#!/usr/bin/env node
'use strict'

const program = require('commander')
const online = require('is-online')
const chalk = require('chalk')
const version = require('./package.json').version
const termhub = require('./lib/')

/**
 * Verify if user is online
 **/
online((error, online) => {
  if (error) throw error
  if (!online) {
    console.log(chalk.red('\n\tYou need a internet connection to use this module.'))
    console.log(chalk.red('\tVerify your connection and try again later.\n'))
    process.exit(0)
  }
})

/**
 * Verify if user pass arguments
 **/
if (process.argv.length <= 2) {
  console.log(chalk.red('\tYou need pass arguments.\n'))
  process.exit(0)
}

/**
 * Set program version
 **/
program
  .version(version)

/**
 * Options
 **/
program
  .option('-c, --clone', 'Clone repository after create')
  .option('-d, --debug', 'Debug mode active')
  .option('-p, --private', 'Create private repository')

/**
 * Create repository
 **/
program
  .command('create <name>')
  .description('Create new repository')

/**
 * Delete repository
 **/
program
  .command('delete <name>')
  .description('Delete respository')

/**
 * Get notifications
 **/
program
  .command('notifications')
  .description('Get notifications')

/**
 * Program action
 **/
program
  .action((command, argument, program) => {
    termhub(command, argument, program)
  })

program.parse(process.argv)
