'use strict'

const prompt = require('prompt')
const github = require('github')
const api = require(__dirname + '/api/index.js')

/**
 * Termhub
 **/
const termhub = function(command, argument, program) {

  const debug = program && program.debug ? true : false

  // Github api instance
  global.Github = new github({
    debug: debug,
    protocol: 'https',
    host: 'api.github.com',
    headers: 'Termhub',
    timeout: 5000,
    Promise: require('bluebird')
  })

  // Prompt schema
  const schema = {
    properties: {
      username: {
        message: 'Your Github username',
        required: true
      },
      password: {
        message: 'Your Github password',
        required: true,
        hidden: true
      }
    }
  }

  /**
   * Start prompt user
   **/
  prompt.start()

  prompt.get(schema, function(error, result) {
    if (error) {
      throw error
    }

    // Basic Github authentication
    Github.authenticate({
      type: "basic",
      username: result.username,
      password: result.password
    })

    switch (command) {
      case 'create':
        api.createRepository(argument, program)
        break
      case 'delete':
        api.deleteRepository(result.username, argument)
      case 'notifications':
        api.getNotifications()
      default:
        console.log('Default')
    }
  })
}

// Expose termhub
module.exports = termhub
